# frozen_string_literal: true

require 'thor'
require 'granule/feature/semantic_react'
require 'granule/feature/devise_semantic'

module Granule
  class CLI < Thor
    include Thor::Actions

    DEFAULT_OPTIONS = '--skip-bundle --skip-webpack-install --skip-test --database=postgresql '\
                      '--webpack=react'\
                      "--skip-turbolinks -m #{File.dirname __dir__}/granule/new/base.rb"

    desc 'new DIRECTORY', 'Create a new rails app'
    def new(name)
      cmd = "rails new #{name} #{DEFAULT_OPTIONS}"

      run(cmd)

      insert_into_file "./#{name}/config/environments/development.rb", after: "Rails.application.configure do\n" do
        <<-RUBY
  # Ignore warnings while in docker environemnts
  config.web_console.whiny_requests = false

        RUBY
      end

      insert_into_file "./#{name}/config/routes.rb", after: "Rails.application.routes.draw do\n" do
        <<-RUBY
  resources :pages

        RUBY
      end
    end

    desc 'feature NAME', 'available: semantic-devise'
    def feature(name)
      service = {
        "semantic-react": Granule::Feature::SemanticReact,
        "semantic-devise": Granule::Feature::DeviseSemantic
      }[name.to_sym]

      return unless service

      service.new.call
    end
  end
end
