# frozen_string_literal: true

module Granule
  module Feature
    class DeviseSemantic < Thor
      include Thor::Actions

      APPLICATION_HTML_ERB_PATH = './app/views/layouts/application.html.erb'
      APPLICATION_PATH = './config/application.rb'
      DEVELOPMENT_PATH = './config/environments/development.rb'
      ROUTES_PATH = './config/routes.rb'

      no_commands do
        def call
          check_files

          copy_file 'devise.rb', './config/initializers/devise.rb'
          copy_file 'user.rb', './app/models/user.rb'
          copy_file 'devise.en.yml', './config/locales/devise.en.yml'
          copy_file 'devise_create_users.rb', "./db/migrate/#{Time.now.strftime('%Y%m%d%H%m%S')}_devise_create_users.rb"

          uncomment_lines APPLICATION_PATH, %r{sprockets/railtie}
          directory 'views', './app/views'
          insert_into_file ROUTES_PATH, "\tdevise_for :users\n",
                           after: "Rails.application.routes.draw do\n"
          insert_into_file APPLICATION_HTML_ERB_PATH,
                           "\t\t<% if current_user %>\n"\
                           "\t\t\t<div class=\"ui pointing secondary menu\">\n"\
                           "\t\t\t\t<a class=\"active item\" href=\"/\">Home</a>\n"\
                           "\t\t\t\t<div class=\"right menu\">\n"\
                           "\t\t\t\t\t<%= link_to 'Logout', destroy_user_session_url, "\
                           "method: :delete, class: 'item' %>\n"\
                           "\t\t\t\t</div>\n"\
                           "\t\t\t</div>\n"\
                           "\t\t<% end %>\n",
                           after: "<body>\n"

          insert_into_file DEVELOPMENT_PATH,
                           "\tconfig.action_mailer.default_url_options = { host: 'localhost', port: 3000 }\n"\
                           "\tconfig.action_mailer.delivery_method = :letter_opener_web\n",
                           after: "Rails.application.configure do\n"
        end
      end

      def self.source_root
        "#{File.dirname(__FILE__)}/devise_semantic"
      end

      private

      def check_files
        [APPLICATION_HTML_ERB_PATH, APPLICATION_PATH, DEVELOPMENT_PATH, ROUTES_PATH].each do |file_path|
          raise Granule::Error, "#{file_path} doesn't exist" unless File.file?(file_path)
        end
      end
    end
  end
end
