# frozen_string_literal: true

module Granule
  module Feature
    class SemanticReact < Thor
      include Thor::Actions

      APPLICATION_JS_PATH = './app/javascript/packs/application.js'
      APPLICATION_HTML_ERB_PATH = './app/views/layouts/application.html.erb'
      PACKAGE_JSON_PATH = './package.json'
      ROUTES_PATH = './config/routes.rb'

      no_commands do
        def call
          check_files

          copy_file 'homes_controller.rb', './app/controllers/homes_controller.rb'
          copy_file 'hello_react.jsx', './app/javascript/packs/hello_react.jsx', force: true
          copy_file 'index.html.erb', './app/views/homes/index.html.erb'

          insert_into_file APPLICATION_JS_PATH,
                           "import 'semantic-ui-css/semantic.min.css';\n\n",
                           before: 'require("@rails/ujs").start()'

          insert_into_file APPLICATION_HTML_ERB_PATH,
                           "\t\t<%= javascript_pack_tag 'hello_react' %>",
                           after: "<%= javascript_pack_tag 'application' %>\n"

          insert_into_file ROUTES_PATH, "\troot 'homes#index'\n", after: "Rails.application.routes.draw do\n"

          insert_into_file PACKAGE_JSON_PATH,
                           "\t\t\"semantic-ui-css\": \"^2.4.1\",\n\t\t\"semantic-ui-react\": \"^0.88.1\",\n",
                           after: "\"dependencies\": {\n"
        end
      end

      def self.source_root
        "#{File.dirname(__FILE__)}/semantic_react"
      end

      private

      def check_files
        [APPLICATION_JS_PATH, ROUTES_PATH, APPLICATION_HTML_ERB_PATH, PACKAGE_JSON_PATH].each do |file_path|
          raise Granule::Error, "#{file_path} doesn't exist" unless File.file?(file_path)
        end
      end
    end
  end
end
